# Nofication-pythonlibrary

A python library that show notification pop-ups

# Requirements

you also need other librarys to make this library work

you need

tkinker

multiprocessing

time

# Importing

install it using pip

pip install nofications

to import nofications you just type in

from nofications import NotificationManager

nofication = NotificationManager()

# How To Use

to show a nofication just type in

nofication.show_notification([message)

replace [message] with a string you wanna notify the user with, and it wont spam the nofications if you accedently keep doing the command becuase it queue up the next one
